@@ -1,6 +1,10 @@
+// SPDX-FileCopyrightText: 2022 The meson-python developers
+//
+// SPDX-License-Identifier: MIT
+
 #include <Python.h>
 
-#include "examplelib.h"
+#include "lib/examplelib.h"
 
 static PyObject* example_sum(PyObject* self, PyObject *args)
 {
